﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Collections;
using System.Globalization;


namespace blogspotxmlgenerator
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            exportFile.Text = Properties.Settings.Default.exportFileName;
            spaceDir.Text = Properties.Settings.Default.spaceDirectory;
            outputDir.Text = Properties.Settings.Default.outputDir;
        }

        private void startButton_Click(object sender, EventArgs e)
        {
            if (exportFile.Text == "" || spaceDir.Text == "" || outputDir.Text == "")
            {

                MessageBox.Show("Please select the required inputs above");
                return;
            }

            StreamWriter report;
            try
            {
                report = new StreamWriter(outputDir.Text + "\\report.txt");
            }
            catch (Exception)
            {
                MessageBox.Show("Error writing to : " + outputDir.Text + "\\report.txt");
                return;
            }


            string blogExport = "";
            StreamReader sr;
            try
            {
                sr = new StreamReader(exportFile.Text);
                while (!sr.EndOfStream)
                {
                    blogExport += sr.ReadLine().Trim().Replace("\r\n", "").Replace("\n", "");
                }
                sr.Close();

            }
            catch (Exception)
            {
                report.WriteLine("Failed to open file: " + exportFile.Text);
            }


            string[] strings = blogExport.Split('"');
            ArrayList pictureURLs = new ArrayList();

            foreach (string url in strings)
            {
                if (url.StartsWith("http://")) // S320 is the smaller verison of the image, suitable for blog format, shile s1600 gives bigger picture.
                    pictureURLs.Add(url);
            }

            report.WriteLine("Found " + pictureURLs.Count + " urls in file: " + exportFile.Text);

            // now use BlogExport to find some key parameters....
            string blogDomain = "";
            try
            {
                blogDomain = blogExport.Substring(blogExport.IndexOf("<link rel"));
                blogDomain = blogDomain.Substring(blogDomain.IndexOf("href='http://") + 13, blogDomain.IndexOf("/feeds/archive'/>") - (blogDomain.IndexOf("href='http://") + 13));
            }
            catch (Exception)
            {
                report.WriteLine("Error extracting domain name:" + blogDomain);
            }

            string blogPosterID = "";
            try
            {
                blogPosterID = blogExport.Substring(blogExport.IndexOf("<id>") + 4, blogExport.IndexOf("</id>") - (blogExport.IndexOf("<id>") + 4));
                blogPosterID = blogPosterID.Substring(blogPosterID.IndexOf("-") + 1, blogPosterID.Substring(blogPosterID.IndexOf("-")).IndexOf(".")-1);
            }
            catch (Exception)
            {
                report.WriteLine("Error extracting blogPosterID:" + blogPosterID);
            }

            string mainBlogTitle = "";
            try
            {
                mainBlogTitle = blogExport.Substring(blogExport.IndexOf("<title"), blogExport.IndexOf("</title>"));
                mainBlogTitle = mainBlogTitle.Substring(mainBlogTitle.IndexOf(">")+1);
                mainBlogTitle = mainBlogTitle.Substring(0,mainBlogTitle.IndexOf("<"));
            }
            catch (Exception)
            {
                report.WriteLine("Error extracting mainBlogTitle:" + mainBlogTitle);
            }

            string blogAuthorProfileURI ="";
            try
            {
                blogAuthorProfileURI = blogExport.Substring(blogExport.IndexOf("<uri>")+5,blogExport.IndexOf("</uri>")-(blogExport.IndexOf("<uri>")+5));
            }
            catch (Exception)
            {
                report.WriteLine("Error extracting blogAuthorProfileURI:" + blogAuthorProfileURI);
            }

            string blogAuthorName ="";
            try
            {
                blogAuthorName = blogExport.Substring(blogExport.IndexOf("<name>") + 6, blogExport.IndexOf("</name>") - (blogExport.IndexOf("<name>") + 6));
            }
            catch (Exception)
            {
                report.WriteLine("Error extracting blogAuthorName:" + blogAuthorName);
            }

            string authorEmail = "";
            try
            {
                authorEmail = blogExport;
                bool foundEmail = false;
                while(authorEmail.IndexOf("<email>")!=-1)
                {
                    authorEmail = authorEmail.Substring(authorEmail.IndexOf("<email>") + 7);
                    if (!authorEmail.StartsWith("noreply@blogger.com"))
                    {
                        authorEmail = authorEmail.Substring(0, authorEmail.IndexOf("</email>"));
                        foundEmail = true;
                        break;
                    }
                }

                if (!foundEmail)
                {
                    authorEmail = "noreply@blogger.com";
                }

            }
            catch (Exception)
            {
                report.WriteLine("Error extracting authorEmail:" + authorEmail);
            }

            ComfirmData comfirm = new ComfirmData(blogDomain, mainBlogTitle, blogPosterID, blogAuthorProfileURI, blogAuthorName, authorEmail);
            comfirm.ShowDialog();

            blogDomain = comfirm.getBlogDomain();
            mainBlogTitle = comfirm.getMainBlogTitle();
            blogPosterID = comfirm.getBlogPosterID();
            blogAuthorProfileURI = comfirm.getBlogAuthorProfileURI();
            blogAuthorName = comfirm.getBlogAuthorName();
            authorEmail = comfirm.getAuthorEmail();

            report.WriteLine("User comfirmed the following data:" +
                "\r\n\tblogDomain:" + blogDomain +
                "\r\n\tmainBlogTitle:" + mainBlogTitle +
                "\r\n\tblogPosterID:" + blogPosterID +
                "\r\n\tblogAuthorProfileURI:" + blogAuthorProfileURI +
                "\r\n\tblogAuthorName:" + blogAuthorName +
                "\r\n\tauthorEmail:" + authorEmail);

            string emptyBlogTemplateText = "";
            try
            {
                sr = new StreamReader("EmptyBlogTemplate.xml");
                emptyBlogTemplateText = sr.ReadToEnd();
                sr.Close();
            }
            catch (Exception)
            {
                report.WriteLine("Failed to open file: EmptyBlogTemplate.xml"); 
                return;
            }

            emptyBlogTemplateText = emptyBlogTemplateText.Replace("{AUTHOR}", blogAuthorName);
            emptyBlogTemplateText = emptyBlogTemplateText.Replace("{AUTHORPROFILE}", blogAuthorProfileURI);
            emptyBlogTemplateText = emptyBlogTemplateText.Replace("{BLOGGERID}", blogPosterID);
            emptyBlogTemplateText = emptyBlogTemplateText.Replace("{BLOGURL}", blogDomain);
            DateTime now = DateTime.Now;
            emptyBlogTemplateText = emptyBlogTemplateText.Replace("{BLOGUPDATED}", now.Year + "-" + now.Month.ToString("D2") + "-" + now.Day.ToString("D2") + "T" + now.Hour.ToString("D2") + ":" + now.Minute.ToString("D2") + ":" + now.Second.ToString("D2") + ".000+02:00");
            emptyBlogTemplateText = emptyBlogTemplateText.Replace("{BLOGTITLE}", mainBlogTitle);
            
            string blogEntryTemplateText = "";
            try{
                sr = new StreamReader("BlogEntryTemplate.xml");
                blogEntryTemplateText = sr.ReadToEnd();
                sr.Close();
            }
            catch (Exception)
            {
                report.WriteLine("Failed to open file: BlogEntryTemplate.xml"); 
                return;
            }

            blogEntryTemplateText = blogEntryTemplateText.Replace("{AUTHOR}", blogAuthorName);
            blogEntryTemplateText = blogEntryTemplateText.Replace("{AUTHORPROFILE}", blogAuthorProfileURI);
            blogEntryTemplateText = blogEntryTemplateText.Replace("{BLOGGERID}", blogPosterID);
            blogEntryTemplateText = blogEntryTemplateText.Replace("{BLOGURL}", blogDomain);
            blogEntryTemplateText = blogEntryTemplateText.Replace("{AUTHOREMAIL}", authorEmail);

            string blogCommentTemplateText = "";
            try{
                sr = new StreamReader("BlogCommentTemplate.xml");
                blogCommentTemplateText = sr.ReadToEnd();
                sr.Close();
            }
            catch (Exception)
            {
                report.WriteLine("Failed to open file: BlogCommentTemplate.xml"); 
                return;
            }

            blogCommentTemplateText = blogCommentTemplateText.Replace("{AUTHORPROFILE}", blogAuthorProfileURI);
            blogCommentTemplateText = blogCommentTemplateText.Replace("{BLOGGERID}", blogPosterID);
            blogCommentTemplateText = blogCommentTemplateText.Replace("{BLOGURL}", blogDomain);


            int start = emptyBlogTemplateText.IndexOf("{INSERTBLOGENTRIESHERE}");
            string emptyBlogTemplateBefore = emptyBlogTemplateText.Substring(0,start);
            string emptyBlogTemplateAfter = emptyBlogTemplateText.Substring(start + 23, emptyBlogTemplateText.Length - start - 23);

            StreamWriter sw;
            try
            {
                sw = new StreamWriter(outputDir.Text + "\\output.xml");
            }
            catch (Exception)
            {
                MessageBox.Show("Error writing to : " + outputDir.Text + "\\output.xml");
                return;
            }

            sw.Write(emptyBlogTemplateBefore);

            string imageString = "&lt;a href=\"{URLS1600}\" imageanchor=\"1\" style=\"clear: left; float: left; margin-bottom: 1em; margin-right: 1em;\"&gt;&lt;img border=\"0\" src=\"{URLS320}\" /&gt;&lt;/a&gt;";
            string lostImage = "http://hardgeek.org/wp-content/uploads/2009/12/broken-link.png";

            DirectoryInfo di = new DirectoryInfo(spaceDir.Text);
            FileInfo[] rgFiles = di.GetFiles("*.html");

            int lostImages = 0;
            int lostImages320 = 0;
            int lostImages1600 = 0;
            double inc = 100.0 / rgFiles.Length;
            double progress = 0;            
            //string allComments = "";

            List<string> allBlogEntries = new List<string>();
            List<string> allBlogEntryDates = new List<string>();
            List<string> allBlogComments = new List<string>();
            List<string> allBlogCommentDates = new List<string>();



            foreach (FileInfo fi in rgFiles)
            {
                if (fi.Name.EndsWith(".html") && fi.Name != "index.html")
                {
                    report.WriteLine("Parsing file: " + fi.Name);
                    string blogEntry = "";
                    try
                    {
                        sr = new StreamReader(fi.FullName);
                        blogEntry = "";
                        while (!sr.EndOfStream)
                        {
                            blogEntry += sr.ReadLine().Trim();
                        }
                        sr.Close();
                    }
                    catch (Exception)
                    {
                        report.WriteLine("Failed to open file: " + fi.FullName);
                        return;
                    }


                    blogEntry = blogEntry.Replace("<span>", "").Replace("</span>", "");

                    start = blogEntry.IndexOf("<title>") + 7;
                    int end = blogEntry.IndexOf("</title>");
                    string blogTitle = "";
                    try
                    {
                        blogTitle = blogEntry.Substring(start, end - start);
                    }
                    catch (Exception)
                    {
                        report.WriteLine("Error extracting blogEntry:" + blogTitle);
                    }

                    // Clean up title for URL usage
                    string blogTitleURL = "";
                    try
                    {
                        blogTitleURL = blogTitle.Replace("&#230;", "ae").Replace("&#248;", "oe").Replace("&#229;", "aa").Replace(" ", "_");
                        blogTitleURL = blogTitleURL.Replace("&#198;", "AE").Replace("&#216;", "OE").Replace("&#197;", "AA").Replace("&#34;", "").Replace(",", "");
                        blogTitleURL = blogTitleURL.Replace("&#35;", "").Replace("&#164;", "").Replace("&#37;", "").Replace("&#38;", "").Replace("&#33;", "");
                        blogTitleURL = blogTitleURL.Replace("#", "").Replace("&", "").Replace(";", "");
                    }
                    catch (Exception)
                    {
                        report.WriteLine("Error extracting blogTitleURL:" + blogTitleURL);
                    }


                    string postID = "";
                    UInt64 postIDint = 0;
                    try
                    {
                        start = blogEntry.IndexOf("id=\"bp-") + 7;
                        end = start + blogEntry.Substring(start).IndexOf("_");
                        postID = blogEntry.Substring(start, end - start);
                        postIDint = UInt64.Parse(postID, System.Globalization.NumberStyles.HexNumber);
                        start = end + 1;
                        // Since this part of the ID always seems to be the same, lets adds the suffix
                        end = blogEntry.Substring(start).IndexOf("-");
                        postID = blogEntry.Substring(start, end);
                        postIDint += UInt32.Parse(postID);
                    }
                    catch (Exception)
                    {
                        report.WriteLine("Error extracting postID:" + postID);
                        report.WriteLine("Error extracting postIDint:" + postIDint);
                    }

                    string published = "";
                    DateTime dt = DateTime.Now;
                    try
                    {
                        start = blogEntry.IndexOf("publish\">") + 9;
                        end = start + blogEntry.Substring(start).IndexOf("</h5>");
                        published = blogEntry.Substring(start, end - start);
                        published = published.Replace("&#58;", ":");

                        /*
                        IFormatProvider culture;

                        // best chance of succeding with current culture?

                        string[] cultures = { "","en-US", "fr-FR", "nb-NO" };

                        cultures[0] = CultureInfo.CurrentCulture.Name;

                        bool foundDate = false;
                        for (int culturesi = 0; culturesi  < cultures.Length;culturesi++)
                        {
                            culture = new CultureInfo(cultures[culturesi], true);
                            try
                            {
                                dt = DateTime.Parse(published,
                                culture,
                                DateTimeStyles.NoCurrentDateDefault);
                                foundDate = true;
                            }
                            catch(Exception)
                            {
                                
                            }
                            if(foundDate) break;
                        }
                        if (!foundDate)
                        {
                            dt = DateTime.Now;
                            report.WriteLine("Error extracting published date, replaced with \"Now\":" + published);
                        }

                        published = dt.Year + "-" + dt.Month.ToString("D2") + "-" + dt.Day.ToString("D2") + "T" + dt.Hour.ToString("D2") + ":" + dt.Minute.ToString("D2") + ":" + dt.Second.ToString("D2") + ".000+02:00";
                         */
                        allBlogEntryDates.Add(published);
                        published = "{BlogPublishDate}";
                    }
                    catch (Exception)
                    {
                        report.WriteLine("Error extracting published:" + published);
                    }

                    string blogContent = "";
                    try
                    {
                        start = blogEntry.IndexOf("class=\"blogpost\">") + 17;
                        blogContent = blogEntry.Substring(start);
                    }
                    catch (Exception)
                    {
                        report.WriteLine("Error extracting blogContent:" + blogContent);
                    }


                    // look for images
                    string afterImage = blogContent;
                    blogContent = "";
                    report.Write("Detecting images in file...");
                    int numberOfImages = 0;
                    while (afterImage.IndexOf("<a href=\"img/") != -1)
                    {
                        // more images!!!
                        numberOfImages++;
                        string beforeImage = "";
                        string image = "";
                        try
                        {
                            start = afterImage.IndexOf("<a href=\"img/");
                            beforeImage = afterImage.Substring(0, start);
                            end = afterImage.Substring(start + 14).IndexOf("\"");
                            image = afterImage.Substring(start + 13, end + 1);
                            end = afterImage.Substring(start).IndexOf("</a>");
                            afterImage = afterImage.Substring(start + end + 4);
                        }
                        catch (Exception)
                        {
                            report.WriteLine("Error extracting beforeImage:" + beforeImage);
                            report.WriteLine("Error extracting image:" + image);
                        }

                        string image320 = "";
                        string image1600 = "";
                        bool found320 = false;
                        bool found1600 = false;
                        foreach (string img in pictureURLs)
                        {
                            if (img.EndsWith(image))
                            {
                                if (!found320 && img.Contains("/s320/"))
                                {
                                    image320 = img;
                                    found320 = true;
                                }
                                if (!found1600 && img.Contains("/s1600/"))
                                {
                                    image1600 = img;
                                    found1600 = true;
                                }
                                if (found320 && found1600)
                                    break;
                            }
                        }

                        if (!found320 && !found1600)
                        {
                            lostImages++;
                            image320 = lostImage;
                            image1600 = lostImage;
                            lostImages320++;
                            lostImages1600++;
                            report.WriteLine("Error finding any image:\"" + image + "\" in list of images");
                        }
                        else if (!found320 || !found1600)
                        {
                            if (!found320)
                            {
                                report.WriteLine("Error finding thumbnail image:\"" + image + "\" in list of images");
                                lostImages320++;
                                image320 = image1600;
                            }
                            else
                            {
                                report.WriteLine("Error finding fullsize image:\"" + image + "\" in list of images");
                                lostImages1600++;
                                image1600 = image320;
                            }
                        }


                        image = imageString.Replace("{URLS320}", image320).Replace("{URLS1600}", image1600);

                        blogContent += "&lt;div class=\"separator\" style=\"clear: both; text-align: left;\"&gt;" + beforeImage + image + "&lt;/div&gt;";

                    }
                    report.WriteLine(numberOfImages + " detected");

                    if (afterImage != "")
                    {
                        try
                        {
                            blogContent += "&lt;div class=\"separator\" style=\"clear: both; text-align: left;\"&gt;"
                                + afterImage.Substring(0, afterImage.IndexOf("</div>"))
                                + "&lt;/div&gt;"
                                + afterImage.Substring(afterImage.IndexOf("</div>"), afterImage.Length - afterImage.IndexOf("</div>"));
                        }
                        catch (Exception)
                        {
                            report.WriteLine("Error adding to blogContent:" + blogContent);
                            report.WriteLine("...from afterImage:" + afterImage);
                        }


                    }

                    blogContent = "<div>" + blogContent;

                    string commentText = "";
                    // Now look for comments to parse...
                    int numberOfComments = 0;
                    if (blogContent.IndexOf("<h3>Comments</h3>") != -1)
                    {
                        // Comments needs to be a seperate XML entry, store the text for processing after the blog entry is added
                        string temp = "";
                        try
                        {
                            start = blogContent.IndexOf("<h3>Comments</h3>") + 17;
                            temp = blogContent.Substring(start);
                            end = temp.IndexOf("</div></div></body>");
                            commentText = blogContent.Substring(start, end);
                        }
                        catch (Exception)
                        {
                            report.WriteLine("Error extracting commentText:" + commentText);
                        }

                        report.Write("Detecting comments in file...");
                        while (commentText.IndexOf("<div id=\"comment") != -1)
                        {
                            // Halleluja, we have comments!


                            numberOfComments++;
                            try
                            {
                                commentText = commentText.Substring(commentText.IndexOf("<div id=\"comment"));
                                commentText = commentText.Substring(commentText.IndexOf("-") + 1);
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentText(2nd):" + commentText);
                            }

                            string commentID = "";
                            try
                            {
                                commentID = commentText.Substring(0, commentText.IndexOf("_"));
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentID:" + commentID);
                            }

                            Int64 commentIDint = -1;
                            try
                            {
                                commentIDint = Int64.Parse(commentID, System.Globalization.NumberStyles.HexNumber);
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error parsing commentID:" + commentID + "to commentIDint:" + commentIDint);
                            }

                            try
                            {
                                commentText = commentText.Substring(commentText.IndexOf("_") + 1);
                                commentID = commentText.Substring(0, commentText.IndexOf("\""));
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentID(2nd):" + commentID);
                            }

                            try
                            {
                                commentIDint += Int32.Parse(commentID);
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error parsing commentID(2nd):" + commentID + "to commentIDint:" + commentIDint);
                            }

                            try
                            {
                                commentText = commentText.Substring(commentText.IndexOf("<h5 id"));
                                commentText = commentText.Substring(commentText.IndexOf("\">") + 2);
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentText(3nd):" + commentText);
                            }

                            string authorAndTime = "";
                            try
                            {
                                authorAndTime = commentText.Substring(0, commentText.IndexOf("</h5>"));
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting authorAndTime:" + authorAndTime);
                            }

                            string commentAuthor = "";
                            try
                            {
                                commentAuthor = authorAndTime.Substring(0, authorAndTime.IndexOf(" -"));
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentAuthor:" + commentAuthor);
                            }
                            string commentPublished = "";
                            try
                            {
                                commentPublished = authorAndTime.Substring(authorAndTime.IndexOf("- ") + 2);
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentPublished:" + commentPublished);
                            }

                            commentPublished = commentPublished.Replace("&#58;", ":");
                            allBlogCommentDates.Add(commentPublished);
                            /*
                            DateTime dtComment = DateTime.Now;
                            try
                            {

                                IFormatProvider culture;

                                // best chance of succeding with current culture?

                                //CultureInfo cults = CultureInfo.GetCultures();

                                string[] cultures = { "", "en-US", "fr-FR", "nb-NO" };

                                cultures[0] = CultureInfo.CurrentCulture.Name;

                                bool foundDate = false;
                                for (int culturesi = 0; culturesi < cultures.Length; culturesi++)
                                {
                                    culture = new CultureInfo(cultures[culturesi], true);
                                    try
                                    {
                                        dtComment = DateTime.Parse(commentPublished,
                                            culture,
                                            DateTimeStyles.NoCurrentDateDefault);
                                            foundDate = true;
                                    }
                                    catch (Exception)
                                    {

                                    }
                                    if (foundDate) break;
                                }
                                if (!foundDate)
                                {
                                    dtComment = DateTime.Now;
                                    report.WriteLine("Error extracting comment date, replaced with \"Now\":" + published);
                                }

                                
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error parsing dtComment:" + commentPublished);
                            }
                            
                            commentPublished = dtComment.Year + "-" + dtComment.Month.ToString("D2") + "-" + dtComment.Day.ToString("D2") + "T" + dtComment.Hour.ToString("D2") + ":" + dtComment.Minute.ToString("D2") + ":" + dtComment.Second.ToString("D2") + ".000+02:00";
                            */
                            commentPublished = "{CommentPublishedDate}";
                            try
                            {
                                commentText = commentText.Substring(commentText.IndexOf("</h5>") + 5);
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentText(4th):" + commentText);
                            }

                            string comment = "";
                            try
                            {
                                comment = commentText.Substring(0, commentText.IndexOf("</div>"));
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting comment:" + comment);
                            }

                            string commentTitle = "";

                            // Clean the shit up....
                            comment = comment.Replace("æ", "&#230;");
                            comment = comment.Replace("ø", "&#248;");
                            comment = comment.Replace("å", "&#229;");
                            comment = comment.Replace("Æ", "&#198;");
                            comment = comment.Replace("Ø", "&#216;");
                            comment = comment.Replace("Å", "&#197;");
                            comment = comment.Replace("<", "&lt;");
                            comment = comment.Replace(">", "&gt;");
                            comment = comment.Replace("'", "&#39;");

                            try
                            {
                                if (comment.Length > 53)
                                {
                                    commentTitle = comment.Substring(0, 50);
                                    if (commentTitle.LastIndexOf("&") > commentTitle.LastIndexOf(";"))
                                    {
                                        commentTitle = commentTitle.Substring(0, commentTitle.LastIndexOf("&"));
                                    }
                                    commentTitle += "...";

                                }
                                else
                                {
                                    commentTitle = comment;
                                }
                            }
                            catch (Exception)
                            {
                                report.WriteLine("Error extracting commentTitle:" + commentTitle);
                            }
                            // We have all the comment data for one comment, lets add it to the template
                            string myComment = blogCommentTemplateText.Replace("{COMMENTID}", commentIDint.ToString());
                            //myComment = myComment.Replace("{PUBLISHED}", commentPublished);
                            //myComment = myComment.Replace("{UPDATED}", commentPublished);
                            myComment = myComment.Replace("{COMMENTTITLE}", commentTitle);
                            myComment = myComment.Replace("{COMMENT}", comment);
                            myComment = myComment.Replace("{POSTID}", postIDint.ToString());
                            //myComment = myComment.Replace("{YEAR}", dtComment.Year.ToString());
                            //myComment = myComment.Replace("{MONTH}", dtComment.Month.ToString("D2"));
                            myComment = myComment.Replace("{TITLEURL}", blogTitleURL);
                            myComment = myComment.Replace("{AUTHOR}", commentAuthor);


                            //allComments += myComment + "\n";
                            allBlogComments.Add(myComment + "\n");

                        }
                    }
                    report.WriteLine(numberOfComments + " detected");

                    // Remove comments from html as they have their own xml entries now
                    try
                    {
                        if (blogContent.IndexOf("<h3>Comments</h3>") != -1)
                            blogContent = blogContent.Substring(0, blogContent.IndexOf("<h3>Comments</h3>"));
                    }
                    catch (Exception)
                    {
                        report.WriteLine("Error removing comments from :" + blogContent);
                    }

                    // Clean the shit up....
                    blogContent = blogContent.Replace("æ", "&#230;");
                    blogContent = blogContent.Replace("ø", "&#248;");
                    blogContent = blogContent.Replace("å", "&#229;");
                    blogContent = blogContent.Replace("Æ", "&#198;");
                    blogContent = blogContent.Replace("Ø", "&#216;");
                    blogContent = blogContent.Replace("Å", "&#197;");
                    blogContent = blogContent.Replace("<", "&lt;");
                    blogContent = blogContent.Replace(">", "&gt;");
                    blogContent = blogContent.Replace("'", "&#39;");


                    string myBlogEntry = blogEntryTemplateText.Replace("{POSTID}", postIDint.ToString());
                    //myBlogEntry = myBlogEntry.Replace("{PUBLISHED}", published);
                    //myBlogEntry = myBlogEntry.Replace("{UPDATED}", published);
                    myBlogEntry = myBlogEntry.Replace("{TITLE}", blogTitle);



                    myBlogEntry = myBlogEntry.Replace("{URLTITLE}", blogTitleURL);

                    myBlogEntry = myBlogEntry.Replace("{CONTENT}", blogContent);
                    //myBlogEntry = myBlogEntry.Replace("{YEAR}", dt.Year.ToString());
                    //myBlogEntry = myBlogEntry.Replace("{MONTH}", dt.Month.ToString("D2"));
                    myBlogEntry = myBlogEntry.Replace("{NUMBEROFCOMMENTS}", numberOfComments.ToString());


                    //sw.Write("\n" + myBlogEntry);
                    allBlogEntries.Add("\n" + myBlogEntry);
                    progress += inc;
                    if (progress > 100)
                        progress = 100;

                    progressBar.Value = (int)progress;


                }
            }

            //string myBlog = emptyBlogTemplateText.Replace("{INSERTBLOGENTRIESHERE}", myBlogEntries);


            //time to do post processing of dates to figure out what is the best match for date format.

            CultureInfo[] cults = CultureInfo.GetCultures(CultureTypes.InstalledWin32Cultures);
            CultureInfo finalCulture = CultureInfo.CurrentCulture;

            report.WriteLine("Detecting culture that works for all dates...");
            bool wrongCulture = false;
            foreach(CultureInfo culture in cults)
            {
                wrongCulture = false;
                if (culture.Name != "")
                {
                    foreach (string blogEntryDate in allBlogEntryDates)
                    {

                        DateTime dtComment = DateTime.Now;

                        try
                        {
                            dtComment = DateTime.Parse(blogEntryDate,
                                culture,
                                DateTimeStyles.NoCurrentDateDefault);
                        }
                        catch (Exception)
                        {
                            wrongCulture = true;
                            break;
                        }
                    }

                    foreach (string blogCommentDate in allBlogCommentDates)
                    {
                        DateTime dtComment = DateTime.Now;

                        try
                        {
                            dtComment = DateTime.Parse(blogCommentDate,
                                culture,
                                DateTimeStyles.NoCurrentDateDefault);
                        }
                        catch (Exception)
                        {
                            wrongCulture = true;
                            break;
                        }

                    }
                    if (!wrongCulture)
                    {
                        finalCulture = culture;
                        report.WriteLine("Correct culture: " + culture.Name);
                        break;
                    }
                    else
                    {
                        report.WriteLine("Wrong culture: " + culture.Name);
                        // loop for next culture
                    }
                }

            }

            // now lets parse the dates and replace them in the blog entries...

            string[] allBlogEntriesArray = allBlogEntries.ToArray();
            string[] allBlogEntryDatesArray = allBlogEntryDates.ToArray();

            string[] allBlogCommentsArray = allBlogComments.ToArray();
            string[] allBlogCommentDatesArray = allBlogCommentDates.ToArray();

            if (allBlogEntriesArray.Length != allBlogEntryDatesArray.Length)
            {
                report.WriteLine("ERROR: allBlogEntriesArray.Length=" + allBlogEntriesArray.Length + " allBlogEntryDatesArray.Length=" + allBlogEntryDatesArray.Length);
                MessageBox.Show("ERROR: Not same number of entries as entries dates");
            }
            if (allBlogCommentsArray.Length != allBlogCommentDatesArray.Length)
            {
                report.WriteLine("ERROR: allBlogCommentsArray.Length=" + allBlogCommentsArray.Length + " allBlogCommentDatesArray.Length=" + allBlogCommentDatesArray.Length);
                MessageBox.Show("ERROR: Not same number of comments as comments dates");
            }


            for (int i = 0; i < allBlogEntriesArray.Length; i++)
            {

                DateTime dtEntry = DateTime.Now;
                try
                {
                    dtEntry = DateTime.Parse(allBlogEntryDatesArray[i],
                        finalCulture,
                        DateTimeStyles.NoCurrentDateDefault);
                }
                catch (Exception)
                {
                    report.WriteLine("All that checking and we still failed!! Blog entry date replaced with NOW");
                    dtEntry = DateTime.Now;
                }
                string published = dtEntry.Year + "-" + dtEntry.Month.ToString("D2") + "-" + dtEntry.Day.ToString("D2") + "T" + dtEntry.Hour.ToString("D2") + ":" + dtEntry.Minute.ToString("D2") + ":" + dtEntry.Second.ToString("D2") + ".000+02:00";
                allBlogEntriesArray[i] = allBlogEntriesArray[i].Replace("{PUBLISHED}", published);
                allBlogEntriesArray[i] = allBlogEntriesArray[i].Replace("{UPDATED}", published);
                allBlogEntriesArray[i] = allBlogEntriesArray[i].Replace("{YEAR}", dtEntry.Year.ToString());
                allBlogEntriesArray[i] = allBlogEntriesArray[i].Replace("{MONTH}", dtEntry.Month.ToString("D2"));

                    //myBlogEntry = myBlogEntry.Replace("{PUBLISHED}", published);
                    //myBlogEntry = myBlogEntry.Replace("{UPDATED}", published);
                    //myBlogEntry = myBlogEntry.Replace("{YEAR}", dt.Year.ToString());
                    //myBlogEntry = myBlogEntry.Replace("{MONTH}", dt.Month.ToString("D2"));

            }

            for (int i = 0; i < allBlogCommentsArray.Length; i++)
            {
                DateTime dtComment = DateTime.Now;

                try
                {
                    dtComment = DateTime.Parse(allBlogCommentDatesArray[i],
                    finalCulture,
                    DateTimeStyles.NoCurrentDateDefault);
                }
                catch (Exception)
                {
                    report.WriteLine("All that checking and we still failed!! Blog comment date replaced with NOW");
                    dtComment = DateTime.Now;
                }

                string commentPublished = dtComment.Year + "-" + dtComment.Month.ToString("D2") + "-" + dtComment.Day.ToString("D2") + "T" + dtComment.Hour.ToString("D2") + ":" + dtComment.Minute.ToString("D2") + ":" + dtComment.Second.ToString("D2") + ".000+02:00";
                allBlogCommentsArray[i] = allBlogCommentsArray[i].Replace("{PUBLISHED}", commentPublished);
                allBlogCommentsArray[i] = allBlogCommentsArray[i].Replace("{UPDATED}", commentPublished);
                allBlogCommentsArray[i] = allBlogCommentsArray[i].Replace("{YEAR}", dtComment.Year.ToString());
                allBlogCommentsArray[i] = allBlogCommentsArray[i].Replace("{MONTH}", dtComment.Month.ToString("D2"));

                            //myComment = myComment.Replace("{PUBLISHED}", commentPublished);
                            //myComment = myComment.Replace("{UPDATED}", commentPublished);
                            //myComment = myComment.Replace("{YEAR}", dtComment.Year.ToString());
                            //myComment = myComment.Replace("{MONTH}", dtComment.Month.ToString("D2"));
            }




            foreach (string output in allBlogEntriesArray)
            {
                sw.Write(output);
            }

            foreach (string output in allBlogCommentsArray)
            {
                sw.Write(output);
            }

            sw.Write(emptyBlogTemplateAfter);
            sw.Close();
            report.Close();
            progressBar.Value = 100;

            MessageBox.Show(lostImages + " images replaced with broken link image\n"
                +lostImages320 + " thumbnail images replaced with fullsize images\n"
                +lostImages1600 + " full size images replaced with thumbnail images\n\n"
                +"Please check report.txt in output dir for details");


        }

        private void button3_Click(object sender, EventArgs e)
        {

        }

        private void progressBar_Click(object sender, EventArgs e)
        {

        }

        private void button1_Click(object sender, EventArgs e)
        {
            // open blogspot export xml file
            OpenFileDialog dlg = new OpenFileDialog();
            if(exportFile.Text != "")
                dlg.InitialDirectory = Path.GetDirectoryName(exportFile.Text);
            dlg.Multiselect = false;
            if (dlg.ShowDialog() == DialogResult.OK)
            {
                exportFile.Text = dlg.FileName;
                Properties.Settings.Default.exportFileName = exportFile.Text;
                Properties.Settings.Default.Save();
            }

        }

        private void button2_Click(object sender, EventArgs e)
        {
            // open space dir
            FolderBrowserDialog dlg = new FolderBrowserDialog();
            if(spaceDir.Text != "")
                dlg.SelectedPath = spaceDir.Text;
            if (dlg.ShowDialog() == DialogResult.OK)
            {
                spaceDir.Text = dlg.SelectedPath;
                Properties.Settings.Default.spaceDirectory = spaceDir.Text;
                Properties.Settings.Default.Save();
            }
        }

        private void label3_Click(object sender, EventArgs e)
        {

        }

        private void button3_Click_1(object sender, EventArgs e)
        {
            // open output dir
            FolderBrowserDialog dlg = new FolderBrowserDialog();
            if (outputDir.Text != "")
                dlg.SelectedPath = outputDir.Text;
            if (dlg.ShowDialog() == DialogResult.OK)
            {
                outputDir.Text = dlg.SelectedPath;
                Properties.Settings.Default.outputDir = outputDir.Text;
                Properties.Settings.Default.Save();
            }
        }
    }
}
